@@ -1,6 +1,6 @@
 from django.forms import ModelForm, Textarea, Select, DateInput
 
-from django_ledger.models.journalentry import JournalEntryModel
+from django_ledger.models.journal_entry import JournalEntryModel
 from django_ledger.settings import DJANGO_LEDGER_FORM_INPUT_CLASSES
 
 
@@ -11,17 +11,10 @@ class JournalEntryModelCreateForm(ModelForm):
         self.USER_MODEL = user_model
         self.LEDGER_PK = ledger_pk
 
-        self.fields['parent'].queryset = JournalEntryModel.on_coa.for_ledger(
-            entity_slug=self.ENTITY_SLUG,
-            user_model=self.USER_MODEL,
-            ledger_pk=self.LEDGER_PK
-        )
-
     class Meta:
         model = JournalEntryModel
         fields = [
-            'parent',
-            'activity',
+            # 'parent',
             'date',
             'description'
         ]
@@ -29,9 +22,6 @@ class JournalEntryModelCreateForm(ModelForm):
             'parent': Select(attrs={
                 'class': DJANGO_LEDGER_FORM_INPUT_CLASSES
             }),
-            'activity': Select(attrs={
-                'class': DJANGO_LEDGER_FORM_INPUT_CLASSES
-            }),
             'date': DateInput(attrs={
                 'class': DJANGO_LEDGER_FORM_INPUT_CLASSES
             }),
@@ -45,20 +35,13 @@ class JournalEntryModelUpdateForm(JournalEntryModelCreateForm):
     class Meta:
         model = JournalEntryModel
         fields = [
-            'parent',
-            'activity',
             'date',
-            'description',
-            'locked',
-            'posted'
+            'description'
         ]
         widgets = {
             'parent': Select(attrs={
                 'class': DJANGO_LEDGER_FORM_INPUT_CLASSES
             }),
-            'activity': Select(attrs={
-                'class': DJANGO_LEDGER_FORM_INPUT_CLASSES
-            }),
             'date': DateInput(attrs={
                 'class': DJANGO_LEDGER_FORM_INPUT_CLASSES
             }),
