@@ -1,14 +1,21 @@
-from django.forms import ModelForm, TextInput
+from django.forms import ModelForm, TextInput, Select
 
 from django_ledger.models.ledger import LedgerModel
 from django_ledger.settings import DJANGO_LEDGER_FORM_INPUT_CLASSES
 
 
 class LedgerModelCreateForm(ModelForm):
+
+    def __init__(self, entity_slug: str, user_model, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.ENTITY_SLUG: str = entity_slug
+        self.USER_MODEL = user_model
+
     class Meta:
         model = LedgerModel
         fields = [
             'name',
+            # 'unit'
         ]
         widgets = {
             'name': TextInput(
@@ -19,11 +26,12 @@ class LedgerModelCreateForm(ModelForm):
         }
 
 
-class LedgerModelUpdateForm(ModelForm):
+class LedgerModelUpdateForm(LedgerModelCreateForm):
     class Meta:
         model = LedgerModel
         fields = [
             'name',
+            # 'unit',
             'posted',
             'locked',
         ]
@@ -31,4 +39,7 @@ class LedgerModelUpdateForm(ModelForm):
             'name': TextInput(attrs={
                 'class': DJANGO_LEDGER_FORM_INPUT_CLASSES
             }),
+            'entity_unit': Select(attrs={
+                'class': DJANGO_LEDGER_FORM_INPUT_CLASSES
+            }),
         }
