@@ -1,3 +1,11 @@
+"""
+Django Ledger created by Miguel Sanda <msanda@arrobalytics.com>.
+Copyright© EDMA Group Inc licensed under the GPLv3 Agreement.
+
+Contributions to this module:
+Miguel Sanda <msanda@arrobalytics.com>
+"""
+
 RATIO_NA = 0
 
 
@@ -20,7 +28,7 @@ class FinancialRatioManager:
         self.gross_profit = tx_digest['group_balance']['GROUP_GROSS_PROFIT']
         self.RATIOS = dict()
 
-    def generate(self):
+    def digest(self):
         self.quick_ratio()
         self.current_ratio()
         self.debt_to_equity()
