@@ -1,3 +1,11 @@
+"""
+Django Ledger created by Miguel Sanda <msanda@arrobalytics.com>.
+Copyright© EDMA Group Inc licensed under the GPLv3 Agreement.
+
+Contributions to this module:
+Miguel Sanda <msanda@arrobalytics.com>
+"""
+
 from random import choice
 from string import ascii_lowercase, digits
 from uuid import uuid4
@@ -35,17 +43,16 @@ class LedgerModelManager(models.Manager):
         return self.get_queryset().filter(posted=True)
 
 
-class LedgerModelAbstract(CreateUpdateMixIn,
-                          IOMixIn):
-
+class LedgerModelAbstract(CreateUpdateMixIn, IOMixIn):
     uuid = models.UUIDField(default=uuid4, editable=False, primary_key=True)
-    name = models.CharField(max_length=150, null=True, blank=True)
+    name = models.CharField(max_length=150, null=True, blank=True, verbose_name=_('Ledger Name'))
     entity = models.ForeignKey('django_ledger.EntityModel',
+                               editable=False,
                                on_delete=models.CASCADE,
-                               verbose_name=_('Entity'),
-                               related_name='ledgers')
-    posted = models.BooleanField(default=False, verbose_name=_('Posted'))
-    locked = models.BooleanField(default=False, verbose_name=_('Locked'))
+                               verbose_name=_('Ledger Entity'))
+    posted = models.BooleanField(default=False, verbose_name=_('Posted Ledger'))
+    locked = models.BooleanField(default=False, verbose_name=_('Locked Ledger'))
+    hidden = models.BooleanField(default=False, verbose_name=_('Hidden Ledger'))
 
     objects = LedgerModelManager()
 
@@ -60,12 +67,15 @@ class LedgerModelAbstract(CreateUpdateMixIn,
             models.Index(fields=['entity', 'locked']),
         ]
 
+    # pylint: disable=bad-option-value
     def __str__(self):
+        # pylint: disable=invalid-str-returned
         return self.name
 
     def get_absolute_url(self):
         return reverse('django_ledger:ledger-detail',
                        kwargs={
+                           # pylint: disable=no-member
                            'entity_slug': self.entity.slug,
                            'ledger_pk': self.uuid
                        })
@@ -73,37 +83,44 @@ class LedgerModelAbstract(CreateUpdateMixIn,
     def get_update_url(self):
         return reverse('django_ledger:ledger-update',
                        kwargs={
+                           # pylint: disable=no-member
                            'entity_slug': self.entity.slug,
                            'ledger_pk': self.uuid
                        })
 
-    def get_coa(self):
-        return self.entity.coa
+    def post(self, commit: bool = False):
+        if not self.posted:
+            self.posted = True
+            if commit:
+                self.save(update_fields=[
+                    'posted',
+                    'updated'
+                ])
 
-    def get_accounts(self):
-        return AccountModel.on_coa.available(coa=self.get_coa())
+    def unpost(self, commit: bool = False):
+        if self.posted:
+            self.posted = False
+            if commit:
+                self.save(update_fields=[
+                    'posted',
+                    'updated'
+                ])
 
-    def get_account(self, code):
-        """
-        Convenience method to get an account model instance from the ledger entity Chart of Accounts.
-        :param code: Account code.
-        :return:
-        """
-        return get_coa_account(coa_model=self.get_coa(),
-                               code=code)
+    def lock(self, commit: bool = False):
+        self.locked = True
+        if commit:
+            self.save(update_fields=[
+                'locked',
+                'updated'
+            ])
 
-    def get_account_balance(self, account_code: str, as_of: str = None):
-        return self.get_jes(accounts=account_code, to_date=as_of)
-
-    # def clean(self):
-    #     if not self.slug:
-    #         r_id = generate_ledger_id()
-    #         slug = slugify(self.name)
-    #         self.slug = f'{slug}-{r_id}'
-    #
-    # def save(self, *args, **kwargs):
-    #     self.clean()
-    #     super().save(*args, **kwargs)
+    def unlock(self, commit: bool = False):
+        self.locked = False
+        if commit:
+            self.save(update_fields=[
+                'locked',
+                'updated'
+            ])
 
 
 class LedgerModel(LedgerModelAbstract):
