@@ -1,6 +1,14 @@
+"""
+Django Ledger created by Miguel Sanda <msanda@arrobalytics.com>.
+Copyright© EDMA Group Inc licensed under the GPLv3 Agreement.
+
+Contributions to this module:
+Miguel Sanda <msanda@arrobalytics.com>
+"""
+
 from datetime import datetime
 from typing import List
-from uuid import uuid4
+from uuid import uuid4, UUID
 
 from django.core.validators import MinValueValidator
 from django.db import models
@@ -11,23 +19,40 @@ from django_ledger.models.accounts import AccountModel
 from django_ledger.models.entity import EntityModel
 from django_ledger.models.ledger import LedgerModel
 from django_ledger.models.mixins import CreateUpdateMixIn
+from django_ledger.models.unit import EntityUnitModel
 
 
+"""
+One of the major model which is used for storing the Transactions recorded in the entity model
+Every transaction which has an financial implication must be recorded in the books
+
+For each transaction, the debits and credits should be matched. Ay transaction will be reflecting in the Financial statements only after the same has been posted
+
+
+"""
+
 class TransactionQuerySet(models.QuerySet):
 
+    """
+    A custom defined Query Set for the TransactionModel.
+    This implements multiple methods or queries that we need to run to get a list of all the transactions.
+    """
     def posted(self):
+        """ Used to select the transaction which are in 'posted' state """
         return self.filter(
             Q(journal_entry__posted=True) &
             Q(journal_entry__ledger__posted=True)
         )
 
     def for_user(self, user_model):
+        """this will authenticate the user and allow the users only to view the transaction for which he is authorized """
         return self.filter(
             Q(journal_entry__ledger__entity__admin=user_model) |
             Q(journal_entry__ledger__entity__managers__in=[user_model])
         )
 
     def for_accounts(self, account_list: List[str or AccountModel]):
+        """This helps to view the transactions for a particular account. We can pass in one particular account of a list of accounts"""
         if len(account_list) > 0 and isinstance(account_list[0], str):
             return self.filter(account__code__in=account_list)
         return self.filter(account__in=account_list)
@@ -35,6 +60,9 @@ class TransactionQuerySet(models.QuerySet):
     def for_roles(self, role_list: List[str]):
         return self.filter(account__role__in=role_list)
 
+    def for_unit(self, unit_slug: str):
+        return self.filter(journal_entry__ledger__unit__slug__exact=unit_slug)
+
     def for_activity(self, activity_list: List[str]):
         return self.filter(journal_entry__activity__in=activity_list)
 
@@ -44,9 +72,6 @@ class TransactionQuerySet(models.QuerySet):
     def from_date(self, from_date: str or datetime):
         return self.filter(journal_entry__date__gte=from_date)
 
-    def for_year(self, year):
-        return self.filter(journal_entry__date__year__exact=year)
-
 
 class TransactionModelAdmin(models.Manager):
 
@@ -59,38 +84,41 @@ class TransactionModelAdmin(models.Manager):
             Q(journal_entry__ledger__entity__managers__in=[user_model])
         )
 
-    # todo: can change to entity only and determine which type it is?...
     def for_entity(self,
                    user_model,
-                   entity_model: EntityModel = None,
                    entity_slug: str = None):
-
-        if not entity_model and not entity_slug:
-            raise ValueError(f'None entity_model or entity_slug were provided.')
-        elif entity_model and entity_slug:
-            raise ValueError(f'Must pass either entity_model or entity_slug, not both.')
-
         qs = self.for_user(user_model=user_model)
-        if entity_model and isinstance(entity_model, EntityModel):
-            return qs.filter(journal_entry__ledger__entity=entity_model)
-        elif entity_slug and isinstance(entity_slug, str):
+        if isinstance(entity_slug, EntityModel):
+            return qs.filter(journal_entry__ledger__entity=entity_slug)
+        elif isinstance(entity_slug, str):
             return qs.filter(journal_entry__ledger__entity__slug__exact=entity_slug)
 
     def for_ledger(self,
                    user_model,
-                   ledger_model: LedgerModel = None,
-                   ledger_pk: str = None):
-
-        if not ledger_model and not ledger_pk:
-            raise ValueError(f'None leger_model or ledger_slug were provided.')
-        elif ledger_model and ledger_pk:
-            raise ValueError(f'Must pass either ledger_model or ledger_slug, not both.')
-
+                   ledger_model: LedgerModel = None):
         qs = self.for_user(user_model=user_model)
-        if ledger_model and isinstance(ledger_model, LedgerModel):
+        if isinstance(ledger_model, LedgerModel):
             return qs.filter(journal_entry__ledger=ledger_model)
-        elif ledger_pk and isinstance(ledger_pk, str):
-            return qs.filter(journal_entry__ledger__uuid__exact=ledger_pk)
+        elif isinstance(ledger_model, str) or isinstance(ledger_model, UUID):
+            return qs.filter(journal_entry__ledger__uuid__exact=ledger_model)
+
+    def for_unit(self,
+                 user_model,
+                 entity_slug: str,
+                 unit_model: EntityUnitModel = None,
+                 unit_slug: str = None):
+
+        if not unit_model and not unit_slug:
+            raise ValueError(f'None unit_model or unit_slug were provided.')
+        elif unit_model and unit_slug:
+            raise ValueError(f'Must pass either unit_model or unit_slug, not both.')
+
+        qs = self.for_entity(user_model=user_model, entity_slug=entity_slug)
+
+        if unit_model and isinstance(unit_model, EntityUnitModel):
+            return qs.filter(journal_entry__entity_unit=unit_model)
+        elif unit_slug and isinstance(unit_slug, str):
+            return qs.filter(journal_entry__entity_unit__slug__exact=unit_slug)
 
     def for_journal_entry(self,
                           user_model,
@@ -155,20 +183,24 @@ class TransactionModelAbstract(CreateUpdateMixIn):
     uuid = models.UUIDField(default=uuid4, editable=False, primary_key=True)
     tx_type = models.CharField(max_length=10, choices=TX_TYPE, verbose_name=_('Tx Type'))
     journal_entry = models.ForeignKey('django_ledger.JournalEntryModel',
-                                      related_name='txs',
+                                      editable=False,
                                       verbose_name=_('Journal Entry'),
-                                      on_delete=models.CASCADE)
+                                      help_text=_('Journal Entry to be associated with this transaction.'),
+                                      on_delete=models.PROTECT)
     account = models.ForeignKey('django_ledger.AccountModel',
-                                related_name='txs',
                                 verbose_name=_('Account'),
-                                on_delete=models.CASCADE)
+                                help_text=_('Account from Chart of Accounts to be associated with this transaction.'),
+                                on_delete=models.PROTECT)
     amount = models.DecimalField(decimal_places=2,
                                  max_digits=20,
                                  null=True,
                                  blank=True,
                                  verbose_name=_('Amount'),
+                                 help_text=_('Account of the transaction.'),
                                  validators=[MinValueValidator(0)])
-    description = models.CharField(max_length=100, null=True, blank=True, verbose_name=_('Tx Description'))
+    description = models.CharField(max_length=100, null=True, blank=True,
+                                   verbose_name=_('Tx Description'),
+                                   help_text=_('A description to be included with this individual transaction'))
     objects = TransactionModelAdmin()
 
     class Meta:
@@ -185,14 +217,17 @@ class TransactionModelAbstract(CreateUpdateMixIn):
         ]
 
     def __str__(self):
+        # pylint: disable=no-member
         return '{x1}-{x2}/{x5}: {x3}/{x4}'.format(x1=self.account.code,
                                                   x2=self.account.name,
                                                   x3=self.amount,
                                                   x4=self.tx_type,
+                                                  # pylint: disable=no-member
                                                   x5=self.account.balance_type)
 
 
 class TransactionModel(TransactionModelAbstract):
     """
-    Base Transaction Model From Abstract
+    Base Transaction Model From Abstract.
+    This is a new documentation.
     """
