@@ -1,15 +1,24 @@
+"""
+Django Ledger created by Miguel Sanda <msanda@arrobalytics.com>.
+Copyright© EDMA Group Inc licensed under the GPLv3 Agreement.
+
+Contributions to this module:
+Miguel Sanda <msanda@arrobalytics.com>
+"""
+
 from django.urls import reverse
 from django.utils.translation import gettext_lazy as _
 from django.views.generic import UpdateView
 
 from django_ledger.forms.coa import ChartOfAccountsModelUpdateForm
 from django_ledger.models.coa import ChartOfAccountModel
+from django_ledger.views.mixins import DjangoLedgerSecurityMixIn
 
 
-class ChartOfAccountsUpdateView(UpdateView):
+class ChartOfAccountsUpdateView(DjangoLedgerSecurityMixIn, UpdateView):
     context_object_name = 'coa'
     slug_url_kwarg = 'coa_slug'
-    template_name = 'django_ledger/coa_update.html'
+    template_name = 'django_ledger/code_of_accounts/coa_update.html'
     form_class = ChartOfAccountsModelUpdateForm
 
     def get_context_data(self, **kwargs):
@@ -20,7 +29,7 @@ class ChartOfAccountsUpdateView(UpdateView):
 
     def get_success_url(self):
         entity_slug = self.kwargs.get('entity_slug')
-        return reverse('django_ledger:entity-detail',
+        return reverse('django_ledger:entity-dashboard',
                        kwargs={
                            'entity_slug': entity_slug
                        })
@@ -29,5 +38,4 @@ class ChartOfAccountsUpdateView(UpdateView):
         return ChartOfAccountModel.objects.for_entity(
             entity_slug=self.kwargs['entity_slug'],
             user_model=self.request.user,
-            coa_slug=self.kwargs['coa_slug']
         )
