@@ -1,3 +1,11 @@
+"""
+Django Ledger created by Miguel Sanda <msanda@arrobalytics.com>.
+Copyright© EDMA Group Inc licensed under the GPLv3 Agreement.
+
+Contributions to this module:
+Miguel Sanda <msanda@arrobalytics.com>
+"""
+
 from itertools import chain
 
 from django.contrib import messages
@@ -14,7 +22,7 @@ from django_ledger.models.accounts import AccountModel
 from django_ledger.models.bank_account import BankAccountModel
 from django_ledger.models.data_import import ImportJobModel, StagedTransactionModel
 from django_ledger.models.entity import EntityModel
-from django_ledger.utils import new_bankaccount_protocol
+from django_ledger.views.mixins import DjangoLedgerSecurityMixIn
 
 
 def digest_staged_txs(cleaned_staged_tx: dict, cash_account: AccountModel):
@@ -38,14 +46,14 @@ def digest_staged_txs(cleaned_staged_tx: dict, cash_account: AccountModel):
     ]
 
 
-class DataImportJobsListView(ListView):
+class DataImportJobsListView(DjangoLedgerSecurityMixIn, ListView):
     PAGE_TITLE = _('Data Import Jobs')
     extra_context = {
         'page_title': PAGE_TITLE,
         'header_title': PAGE_TITLE
     }
     context_object_name = 'import_jobs'
-    template_name = 'django_ledger/data_import_job_list.html'
+    template_name = 'django_ledger/data_import/data_import_job_list.html'
 
     def get_queryset(self):
         return ImportJobModel.objects.for_entity(
@@ -54,8 +62,8 @@ class DataImportJobsListView(ListView):
         )
 
 
-class DataImportOFXFileView(FormView):
-    template_name = 'django_ledger/data_import_ofx.html'
+class DataImportOFXFileView(DjangoLedgerSecurityMixIn, FormView):
+    template_name = 'django_ledger/data_import/data_import_ofx.html'
     PAGE_TITLE = _('OFX File Import')
     extra_context = {
         'page_title': PAGE_TITLE,
@@ -110,14 +118,10 @@ class DataImportOFXFileView(FormView):
 
             for ba in new_bank_accs:
                 ba.clean()
-
-            new_bank_accs = [
-                new_bankaccount_protocol(
-                    bank_account_model=ba,
+                ba.configure(
                     entity_slug=entity_model,
                     user_model=self.request.user
-                ) for ba in new_bank_accs
-            ]
+                )
             BankAccountModel.objects.bulk_create(new_bank_accs)
 
             # fetching all bank account models again
@@ -148,8 +152,8 @@ class DataImportOFXFileView(FormView):
         return super().form_valid(form=form)
 
 
-class DataImportJobDetailView(DetailView):
-    template_name = 'django_ledger/data_import_job_txs.html'
+class DataImportJobDetailView(DjangoLedgerSecurityMixIn, DetailView):
+    template_name = 'django_ledger/data_import/data_import_job_txs.html'
     PAGE_TITLE = _('Import Job Staged Txs')
     context_object_name = 'import_job'
     pk_url_kwarg = 'job_pk'
